@@ -33,7 +33,7 @@ paho_rc_to_error = {
     mqtt.MQTT_ERR_NOMEM: exceptions.ProtocolClientError,
     mqtt.MQTT_ERR_PROTOCOL: exceptions.ProtocolClientError,
     mqtt.MQTT_ERR_INVAL: exceptions.ProtocolClientError,
-    mqtt.MQTT_ERR_NO_CONN: exceptions.ConnectionDroppedError,
+    mqtt.MQTT_ERR_NO_CONN: exceptions.NoConnectionError,
     mqtt.MQTT_ERR_CONN_REFUSED: exceptions.ConnectionFailedError,
     mqtt.MQTT_ERR_NOT_FOUND: exceptions.ConnectionFailedError,
     mqtt.MQTT_ERR_CONN_LOST: exceptions.ConnectionDroppedError,
@@ -436,7 +436,7 @@ class MQTTTransport(object):
             raise _create_error_from_rc_code(rc)
         self._mqtt_client.loop_start()
 
-    def disconnect(self):
+    def disconnect(self, clear_pending=False):
         """
         Disconnect from the MQTT broker.
 
@@ -463,6 +463,13 @@ class MQTTTransport(object):
             # to this error.
             err = _create_error_from_rc_code(rc)
             raise err
+        else:
+            # Clear pending ops if instructed, but only if the disconnect was successful.
+            # Technically the disconnect could still fail upon response, however that would then
+            # cause a force disconnect via the on_disconnect handler, thus it is safe to clear
+            # ops here and now.
+            if clear_pending:
+                self._op_manager.cancel_all_operations()
 
     def subscribe(self, topic, qos=1, callback=None):
         """
@@ -654,3 +661,32 @@ class OperationManager(object):
             else:
                 # fully expected.  QOS=1 means we might get 2 PUBACKs
                 logger.debug("No callback set for MID: {}".format(mid))
+
+    def cancel_all_operations(self):
+        """Complete all pending operations with cancellation, removing MID tracking"""
+        logger.debug("Cancelling all pending operations")
+        with self._lock:
+            # Clear pending operations
+            pending_ops = list(self._pending_operation_callbacks.items())
+            for pending_op in pending_ops:
+                mid = pending_op[0]
+                del self._pending_operation_callbacks[mid]
+
+            # Clear unknown responses
+            unknown_mids = [mid for mid in self._unknown_operation_completions]
+            for mid in unknown_mids:
+                del self._unknown_operation_completions[mid]
+
+        # Trigger cancel in pending operation callbacks
+        for pending_op in pending_ops:
+            mid = pending_op[0]
+            callback = pending_op[1]
+            if callback:
+                logger.debug("Cancelling {} - Triggering callback".format(mid))
+                try:
+                    callback(cancelled=True)
+                except Exception:
+                    logger.error("Unexpected error calling callback for MID: {}".format(mid))
+                    logger.error(traceback.format_exc())
+            else:
+                logger.debug("Cancelling {} - No callback set for MID".format(mid))
