@@ -34,6 +34,9 @@ def _validate_kwargs(exclude=[], **kwargs):
         "proxy_options",
         "sastoken_ttl",
         "keep_alive",
+        "auto_connect",
+        "connection_retry",
+        "connection_retry_interval",
     ]
 
     for kwarg in kwargs:
@@ -50,6 +53,9 @@ def _get_config_kwargs(**kwargs):
         "server_verification_cert",
         "proxy_options",
         "keep_alive",
+        "auto_connect",
+        "connection_retry",
+        "connection_retry_interval",
     ]
 
     config_kwargs = {}
@@ -218,6 +224,11 @@ class AbstractIoTHubClient(object):
             broker. If no other messages are being exchanged, this controls the
             rate at which the client will send ping messages to the broker.
             If not provided default value of 60 secs will be used.
+        :param bool auto_connect: Automatically connect the client to IoTHub when a method is
+            invoked which requires a connection to be established. (Default: True)
+        :param bool connection_retry: Attempt to re-establish a dropped connection (Default: True)
+        :param int connection_retry_interval: Interval, in seconds, between attempts to
+            re-establish a dropped connection (Default: 10)
 
         :raises: ValueError if given an invalid connection_string.
         :raises: TypeError if given an unsupported parameter.
@@ -287,6 +298,11 @@ class AbstractIoTHubClient(object):
             broker. If no other messages are being exchanged, this controls the
             rate at which the client will send ping messages to the broker.
             If not provided default value of 60 secs will be used.
+        :param bool auto_connect: Automatically connect the client to IoTHub when a method is
+            invoked which requires a connection to be established. (Default: True)
+        :param bool connection_retry: Attempt to re-establish a dropped connection (Default: True)
+        :param int connection_retry_interval: Interval, in seconds, between attempts to
+            re-establish a dropped connection (Default: 10)
 
         :raises: TypeError if given an unsupported parameter.
         :raises: ValueError if the sastoken parameter is invalid.
@@ -420,6 +436,11 @@ class AbstractIoTHubDeviceClient(AbstractIoTHubClient):
             broker. If no other messages are being exchanged, this controls the
             rate at which the client will send ping messages to the broker.
             If not provided default value of 60 secs will be used.
+        :param bool auto_connect: Automatically connect the client to IoTHub when a method is
+            invoked which requires a connection to be established. (Default: True)
+        :param bool connection_retry: Attempt to re-establish a dropped connection (Default: True)
+        :param int connection_retry_interval: Interval, in seconds, between attempts to
+            re-establish a dropped connection (Default: 10)
 
         :raises: TypeError if given an unsupported parameter.
 
@@ -470,6 +491,11 @@ class AbstractIoTHubDeviceClient(AbstractIoTHubClient):
             broker. If no other messages are being exchanged, this controls the
             rate at which the client will send ping messages to the broker.
             If not provided default value of 60 secs will be used.
+        :param bool auto_connect: Automatically connect the client to IoTHub when a method is
+            invoked which requires a connection to be established. (Default: True)
+        :param bool connection_retry: Attempt to re-establish a dropped connection (Default: True)
+        :param int connection_retry_interval: Interval, in seconds, between attempts to
+            re-establish a dropped connection (Default: 10)
 
         :raises: TypeError if given an unsupported parameter.
         :raises: ValueError if the provided parameters are invalid.
@@ -543,6 +569,11 @@ class AbstractIoTHubModuleClient(AbstractIoTHubClient):
             broker. If no other messages are being exchanged, this controls the
             rate at which the client will send ping messages to the broker.
             If not provided default value of 60 secs will be used.
+        :param bool auto_connect: Automatically connect the client to IoTHub when a method is
+            invoked which requires a connection to be established. (Default: True)
+        :param bool connection_retry: Attempt to re-establish a dropped connection (Default: True)
+        :param int connection_retry_interval: Interval, in seconds, between attempts to
+            re-establish a dropped connection (Default: 10)
 
         :raises: OSError if the IoT Edge container is not configured correctly.
         :raises: ValueError if debug variables are invalid.
@@ -688,6 +719,11 @@ class AbstractIoTHubModuleClient(AbstractIoTHubClient):
             broker. If no other messages are being exchanged, this controls the
             rate at which the client will send ping messages to the broker.
             If not provided default value of 60 secs will be used.
+        :param bool auto_connect: Automatically connect the client to IoTHub when a method is
+            invoked which requires a connection to be established. (Default: True)
+        :param bool connection_retry: Attempt to re-establish a dropped connection (Default: True)
+        :param int connection_retry_interval: Interval, in seconds, between attempts to
+            re-establish a dropped connection (Default: 10)
 
         :raises: TypeError if given an unsupported parameter.
 
