@@ -83,7 +83,7 @@ class HTTPPipeline(object):
         logger.debug("HTTPPipeline invoke_method called")
         if not self._pipeline.pipeline_configuration.method_invoke:
             # If this parameter is not set, that means that the pipeline was not generated by the edge environment. Method invoke only works for clients generated using the edge environment.
-            error = pipeline_exceptions.PipelineError(
+            error = pipeline_exceptions.PipelineRuntimeError(
                 "invoke_method called, but it is only supported on module clients generated from an edge environment. If you are not using a module generated from an edge environment, you cannot use invoke_method"
             )
             return callback(error=error)
@@ -117,7 +117,7 @@ class HTTPPipeline(object):
         logger.debug("HTTPPipeline get_storage_info_for_blob called")
         if not self._pipeline.pipeline_configuration.blob_upload:
             # If this parameter is not set, that means this is not a device client. Upload to blob is not supported on module clients.
-            error = pipeline_exceptions.PipelineError(
+            error = pipeline_exceptions.PipelineRuntimeError(
                 "get_storage_info_for_blob called, but it is only supported for use with device clients. Ensure you are using a device client."
             )
             return callback(error=error)
@@ -155,7 +155,7 @@ class HTTPPipeline(object):
         logger.debug("HTTPPipeline notify_blob_upload_status called")
         if not self._pipeline.pipeline_configuration.blob_upload:
             # If this parameter is not set, that means this is not a device client. Upload to blob is not supported on module clients.
-            error = pipeline_exceptions.PipelineError(
+            error = pipeline_exceptions.PipelineRuntimeError(
                 "notify_blob_upload_status called, but it is only supported for use with device clients. Ensure you are using a device client."
             )
             return callback(error=error)
